
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include "gstmpegts-enumtypes.h"
#include "gstmpegtssection.h"
#include "gst-atsc-section.h"
#include "gst-dvb-section.h"
#include "gst-scte-section.h"
#include "gst-hdmv-section.h"
#include "gstmpegtsdescriptor.h"
#include "gst-atsc-descriptor.h"
#include "gst-dvb-descriptor.h"
#include "gst-isdb-descriptor.h"
#include "mpegts-prelude.h"
#include "mpegts.h"

#define C_ENUM(v) ((gint) v)
#define C_FLAGS(v) ((guint) v)

/* enumerations from "gst-atsc-descriptor.h" */

GType
gst_mpegts_atsc_descriptor_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_DESC_ATSC_STUFFING), "GST_MTS_DESC_ATSC_STUFFING", "stuffing" },
    { C_ENUM(GST_MTS_DESC_ATSC_AC3), "GST_MTS_DESC_ATSC_AC3", "ac3" },
    { C_ENUM(GST_MTS_DESC_ATSC_CAPTION_SERVICE), "GST_MTS_DESC_ATSC_CAPTION_SERVICE", "caption-service" },
    { C_ENUM(GST_MTS_DESC_ATSC_CONTENT_ADVISORY), "GST_MTS_DESC_ATSC_CONTENT_ADVISORY", "content-advisory" },
    { C_ENUM(GST_MTS_DESC_ATSC_EXTENDED_CHANNEL_NAME), "GST_MTS_DESC_ATSC_EXTENDED_CHANNEL_NAME", "extended-channel-name" },
    { C_ENUM(GST_MTS_DESC_ATSC_SERVICE_LOCATION), "GST_MTS_DESC_ATSC_SERVICE_LOCATION", "service-location" },
    { C_ENUM(GST_MTS_DESC_ATSC_TIME_SHIFTED_SERVICE), "GST_MTS_DESC_ATSC_TIME_SHIFTED_SERVICE", "time-shifted-service" },
    { C_ENUM(GST_MTS_DESC_ATSC_COMPONENT_NAME), "GST_MTS_DESC_ATSC_COMPONENT_NAME", "component-name" },
    { C_ENUM(GST_MTS_DESC_ATSC_DCC_DEPARTING_REQUEST), "GST_MTS_DESC_ATSC_DCC_DEPARTING_REQUEST", "dcc-departing-request" },
    { C_ENUM(GST_MTS_DESC_ATSC_DCC_ARRIVING_REQUEST), "GST_MTS_DESC_ATSC_DCC_ARRIVING_REQUEST", "dcc-arriving-request" },
    { C_ENUM(GST_MTS_DESC_ATSC_REDISTRIBUTION_CONTROL), "GST_MTS_DESC_ATSC_REDISTRIBUTION_CONTROL", "redistribution-control" },
    { C_ENUM(GST_MTS_DESC_ATSC_GENRE), "GST_MTS_DESC_ATSC_GENRE", "genre" },
    { C_ENUM(GST_MTS_DESC_ATSC_PRIVATE_INFORMATION), "GST_MTS_DESC_ATSC_PRIVATE_INFORMATION", "private-information" },
    { C_ENUM(GST_MTS_DESC_ATSC_EAC3), "GST_MTS_DESC_ATSC_EAC3", "eac3" },
    { C_ENUM(GST_MTS_DESC_ATSC_ENHANCED_SIGNALING), "GST_MTS_DESC_ATSC_ENHANCED_SIGNALING", "enhanced-signaling" },
    { C_ENUM(GST_MTS_DESC_ATSC_DATA_SERVICE), "GST_MTS_DESC_ATSC_DATA_SERVICE", "data-service" },
    { C_ENUM(GST_MTS_DESC_ATSC_PID_COUNT), "GST_MTS_DESC_ATSC_PID_COUNT", "pid-count" },
    { C_ENUM(GST_MTS_DESC_ATSC_DOWNLOAD_DESCRIPTOR), "GST_MTS_DESC_ATSC_DOWNLOAD_DESCRIPTOR", "download-descriptor" },
    { C_ENUM(GST_MTS_DESC_ATSC_MULTIPROTOCOL_ENCAPSULATION), "GST_MTS_DESC_ATSC_MULTIPROTOCOL_ENCAPSULATION", "multiprotocol-encapsulation" },
    { C_ENUM(GST_MTS_DESC_ATSC_MODULE_LINK), "GST_MTS_DESC_ATSC_MODULE_LINK", "module-link" },
    { C_ENUM(GST_MTS_DESC_ATSC_CRC32), "GST_MTS_DESC_ATSC_CRC32", "crc32" },
    { C_ENUM(GST_MTS_DESC_ATSC_GROUP_LINK), "GST_MTS_DESC_ATSC_GROUP_LINK", "group-link" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsATSCDescriptorType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

/* enumerations from "gst-atsc-section.h" */

GType
gst_mpegts_section_atsc_table_id_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_MASTER_GUIDE), "GST_MTS_TABLE_ID_ATSC_MASTER_GUIDE", "master-guide" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_TERRESTRIAL_VIRTUAL_CHANNEL), "GST_MTS_TABLE_ID_ATSC_TERRESTRIAL_VIRTUAL_CHANNEL", "terrestrial-virtual-channel" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_CABLE_VIRTUAL_CHANNEL), "GST_MTS_TABLE_ID_ATSC_CABLE_VIRTUAL_CHANNEL", "cable-virtual-channel" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_RATING_REGION), "GST_MTS_TABLE_ID_ATSC_RATING_REGION", "rating-region" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_EVENT_INFORMATION), "GST_MTS_TABLE_ID_ATSC_EVENT_INFORMATION", "event-information" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_CHANNEL_OR_EVENT_EXTENDED_TEXT), "GST_MTS_TABLE_ID_ATSC_CHANNEL_OR_EVENT_EXTENDED_TEXT", "channel-or-event-extended-text" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_SYSTEM_TIME), "GST_MTS_TABLE_ID_ATSC_SYSTEM_TIME", "system-time" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_DATA_EVENT), "GST_MTS_TABLE_ID_ATSC_DATA_EVENT", "data-event" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_DATA_SERVICE), "GST_MTS_TABLE_ID_ATSC_DATA_SERVICE", "data-service" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_PROGRAM_IDENTIFIER), "GST_MTS_TABLE_ID_ATSC_PROGRAM_IDENTIFIER", "program-identifier" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_NETWORK_RESOURCE), "GST_MTS_TABLE_ID_ATSC_NETWORK_RESOURCE", "network-resource" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_LONG_TERM_SERVICE), "GST_MTS_TABLE_ID_ATSC_LONG_TERM_SERVICE", "long-term-service" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_DIRECTED_CHANNEL_CHANGE), "GST_MTS_TABLE_ID_ATSC_DIRECTED_CHANNEL_CHANGE", "directed-channel-change" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_DIRECTED_CHANNEL_CHANGE_SECTION_CODE), "GST_MTS_TABLE_ID_ATSC_DIRECTED_CHANNEL_CHANGE_SECTION_CODE", "directed-channel-change-section-code" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_AGGREGATE_EVENT_INFORMATION), "GST_MTS_TABLE_ID_ATSC_AGGREGATE_EVENT_INFORMATION", "aggregate-event-information" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_AGGREGATE_EXTENDED_TEXT), "GST_MTS_TABLE_ID_ATSC_AGGREGATE_EXTENDED_TEXT", "aggregate-extended-text" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_AGGREGATE_DATA_EVENT), "GST_MTS_TABLE_ID_ATSC_AGGREGATE_DATA_EVENT", "aggregate-data-event" },
    { C_ENUM(GST_MTS_TABLE_ID_ATSC_SATELLITE_VIRTUAL_CHANNEL), "GST_MTS_TABLE_ID_ATSC_SATELLITE_VIRTUAL_CHANNEL", "satellite-virtual-channel" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsSectionATSCTableID"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_atsc_stream_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_ATSC_DCII_VIDEO), "GST_MPEGTS_STREAM_TYPE_ATSC_DCII_VIDEO", "dcii-video" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_ATSC_AUDIO_AC3), "GST_MPEGTS_STREAM_TYPE_ATSC_AUDIO_AC3", "audio-ac3" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_ATSC_SUBTITLING), "GST_MPEGTS_STREAM_TYPE_ATSC_SUBTITLING", "subtitling" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_ATSC_ISOCH_DATA), "GST_MPEGTS_STREAM_TYPE_ATSC_ISOCH_DATA", "isoch-data" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_ATSC_SIT), "GST_MPEGTS_STREAM_TYPE_ATSC_SIT", "sit" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_ATSC_AUDIO_EAC3), "GST_MPEGTS_STREAM_TYPE_ATSC_AUDIO_EAC3", "audio-eac3" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_ATSC_AUDIO_DTS_HD), "GST_MPEGTS_STREAM_TYPE_ATSC_AUDIO_DTS_HD", "audio-dts-hd" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsATSCStreamType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_atsc_mgt_table_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_ATSC_MGT_TABLE_TYPE_EIT0), "GST_MPEGTS_ATSC_MGT_TABLE_TYPE_EIT0", "eit0" },
    { C_ENUM(GST_MPEGTS_ATSC_MGT_TABLE_TYPE_EIT127), "GST_MPEGTS_ATSC_MGT_TABLE_TYPE_EIT127", "eit127" },
    { C_ENUM(GST_MPEGTS_ATSC_MGT_TABLE_TYPE_ETT0), "GST_MPEGTS_ATSC_MGT_TABLE_TYPE_ETT0", "ett0" },
    { C_ENUM(GST_MPEGTS_ATSC_MGT_TABLE_TYPE_ETT127), "GST_MPEGTS_ATSC_MGT_TABLE_TYPE_ETT127", "ett127" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsAtscMGTTableType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

/* enumerations from "gst-dvb-descriptor.h" */

GType
gst_mpegts_dvb_descriptor_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_DESC_DVB_NETWORK_NAME), "GST_MTS_DESC_DVB_NETWORK_NAME", "network-name" },
    { C_ENUM(GST_MTS_DESC_DVB_SERVICE_LIST), "GST_MTS_DESC_DVB_SERVICE_LIST", "service-list" },
    { C_ENUM(GST_MTS_DESC_DVB_STUFFING), "GST_MTS_DESC_DVB_STUFFING", "stuffing" },
    { C_ENUM(GST_MTS_DESC_DVB_SATELLITE_DELIVERY_SYSTEM), "GST_MTS_DESC_DVB_SATELLITE_DELIVERY_SYSTEM", "satellite-delivery-system" },
    { C_ENUM(GST_MTS_DESC_DVB_CABLE_DELIVERY_SYSTEM), "GST_MTS_DESC_DVB_CABLE_DELIVERY_SYSTEM", "cable-delivery-system" },
    { C_ENUM(GST_MTS_DESC_DVB_VBI_DATA), "GST_MTS_DESC_DVB_VBI_DATA", "vbi-data" },
    { C_ENUM(GST_MTS_DESC_DVB_VBI_TELETEXT), "GST_MTS_DESC_DVB_VBI_TELETEXT", "vbi-teletext" },
    { C_ENUM(GST_MTS_DESC_DVB_BOUQUET_NAME), "GST_MTS_DESC_DVB_BOUQUET_NAME", "bouquet-name" },
    { C_ENUM(GST_MTS_DESC_DVB_SERVICE), "GST_MTS_DESC_DVB_SERVICE", "service" },
    { C_ENUM(GST_MTS_DESC_DVB_COUNTRY_AVAILABILITY), "GST_MTS_DESC_DVB_COUNTRY_AVAILABILITY", "country-availability" },
    { C_ENUM(GST_MTS_DESC_DVB_LINKAGE), "GST_MTS_DESC_DVB_LINKAGE", "linkage" },
    { C_ENUM(GST_MTS_DESC_DVB_NVOD_REFERENCE), "GST_MTS_DESC_DVB_NVOD_REFERENCE", "nvod-reference" },
    { C_ENUM(GST_MTS_DESC_DVB_TIME_SHIFTED_SERVICE), "GST_MTS_DESC_DVB_TIME_SHIFTED_SERVICE", "time-shifted-service" },
    { C_ENUM(GST_MTS_DESC_DVB_SHORT_EVENT), "GST_MTS_DESC_DVB_SHORT_EVENT", "short-event" },
    { C_ENUM(GST_MTS_DESC_DVB_EXTENDED_EVENT), "GST_MTS_DESC_DVB_EXTENDED_EVENT", "extended-event" },
    { C_ENUM(GST_MTS_DESC_DVB_TIME_SHIFTED_EVENT), "GST_MTS_DESC_DVB_TIME_SHIFTED_EVENT", "time-shifted-event" },
    { C_ENUM(GST_MTS_DESC_DVB_COMPONENT), "GST_MTS_DESC_DVB_COMPONENT", "component" },
    { C_ENUM(GST_MTS_DESC_DVB_MOSAIC), "GST_MTS_DESC_DVB_MOSAIC", "mosaic" },
    { C_ENUM(GST_MTS_DESC_DVB_STREAM_IDENTIFIER), "GST_MTS_DESC_DVB_STREAM_IDENTIFIER", "stream-identifier" },
    { C_ENUM(GST_MTS_DESC_DVB_CA_IDENTIFIER), "GST_MTS_DESC_DVB_CA_IDENTIFIER", "ca-identifier" },
    { C_ENUM(GST_MTS_DESC_DVB_CONTENT), "GST_MTS_DESC_DVB_CONTENT", "content" },
    { C_ENUM(GST_MTS_DESC_DVB_PARENTAL_RATING), "GST_MTS_DESC_DVB_PARENTAL_RATING", "parental-rating" },
    { C_ENUM(GST_MTS_DESC_DVB_TELETEXT), "GST_MTS_DESC_DVB_TELETEXT", "teletext" },
    { C_ENUM(GST_MTS_DESC_DVB_TELEPHONE), "GST_MTS_DESC_DVB_TELEPHONE", "telephone" },
    { C_ENUM(GST_MTS_DESC_DVB_LOCAL_TIME_OFFSET), "GST_MTS_DESC_DVB_LOCAL_TIME_OFFSET", "local-time-offset" },
    { C_ENUM(GST_MTS_DESC_DVB_SUBTITLING), "GST_MTS_DESC_DVB_SUBTITLING", "subtitling" },
    { C_ENUM(GST_MTS_DESC_DVB_TERRESTRIAL_DELIVERY_SYSTEM), "GST_MTS_DESC_DVB_TERRESTRIAL_DELIVERY_SYSTEM", "terrestrial-delivery-system" },
    { C_ENUM(GST_MTS_DESC_DVB_MULTILINGUAL_NETWORK_NAME), "GST_MTS_DESC_DVB_MULTILINGUAL_NETWORK_NAME", "multilingual-network-name" },
    { C_ENUM(GST_MTS_DESC_DVB_MULTILINGUAL_BOUQUET_NAME), "GST_MTS_DESC_DVB_MULTILINGUAL_BOUQUET_NAME", "multilingual-bouquet-name" },
    { C_ENUM(GST_MTS_DESC_DVB_MULTILINGUAL_SERVICE_NAME), "GST_MTS_DESC_DVB_MULTILINGUAL_SERVICE_NAME", "multilingual-service-name" },
    { C_ENUM(GST_MTS_DESC_DVB_MULTILINGUAL_COMPONENT), "GST_MTS_DESC_DVB_MULTILINGUAL_COMPONENT", "multilingual-component" },
    { C_ENUM(GST_MTS_DESC_DVB_PRIVATE_DATA_SPECIFIER), "GST_MTS_DESC_DVB_PRIVATE_DATA_SPECIFIER", "private-data-specifier" },
    { C_ENUM(GST_MTS_DESC_DVB_SERVICE_MOVE), "GST_MTS_DESC_DVB_SERVICE_MOVE", "service-move" },
    { C_ENUM(GST_MTS_DESC_DVB_SHORT_SMOOTHING_BUFFER), "GST_MTS_DESC_DVB_SHORT_SMOOTHING_BUFFER", "short-smoothing-buffer" },
    { C_ENUM(GST_MTS_DESC_DVB_FREQUENCY_LIST), "GST_MTS_DESC_DVB_FREQUENCY_LIST", "frequency-list" },
    { C_ENUM(GST_MTS_DESC_DVB_PARTIAL_TRANSPORT_STREAM), "GST_MTS_DESC_DVB_PARTIAL_TRANSPORT_STREAM", "partial-transport-stream" },
    { C_ENUM(GST_MTS_DESC_DVB_DATA_BROADCAST), "GST_MTS_DESC_DVB_DATA_BROADCAST", "data-broadcast" },
    { C_ENUM(GST_MTS_DESC_DVB_SCRAMBLING), "GST_MTS_DESC_DVB_SCRAMBLING", "scrambling" },
    { C_ENUM(GST_MTS_DESC_DVB_DATA_BROADCAST_ID), "GST_MTS_DESC_DVB_DATA_BROADCAST_ID", "data-broadcast-id" },
    { C_ENUM(GST_MTS_DESC_DVB_TRANSPORT_STREAM), "GST_MTS_DESC_DVB_TRANSPORT_STREAM", "transport-stream" },
    { C_ENUM(GST_MTS_DESC_DVB_DSNG), "GST_MTS_DESC_DVB_DSNG", "dsng" },
    { C_ENUM(GST_MTS_DESC_DVB_PDC), "GST_MTS_DESC_DVB_PDC", "pdc" },
    { C_ENUM(GST_MTS_DESC_DVB_AC3), "GST_MTS_DESC_DVB_AC3", "ac3" },
    { C_ENUM(GST_MTS_DESC_DVB_ANCILLARY_DATA), "GST_MTS_DESC_DVB_ANCILLARY_DATA", "ancillary-data" },
    { C_ENUM(GST_MTS_DESC_DVB_CELL_LIST), "GST_MTS_DESC_DVB_CELL_LIST", "cell-list" },
    { C_ENUM(GST_MTS_DESC_DVB_CELL_FREQUENCY_LINK), "GST_MTS_DESC_DVB_CELL_FREQUENCY_LINK", "cell-frequency-link" },
    { C_ENUM(GST_MTS_DESC_DVB_ANNOUNCEMENT_SUPPORT), "GST_MTS_DESC_DVB_ANNOUNCEMENT_SUPPORT", "announcement-support" },
    { C_ENUM(GST_MTS_DESC_DVB_APPLICATION_SIGNALLING), "GST_MTS_DESC_DVB_APPLICATION_SIGNALLING", "application-signalling" },
    { C_ENUM(GST_MTS_DESC_DVB_ADAPTATION_FIELD_DATA), "GST_MTS_DESC_DVB_ADAPTATION_FIELD_DATA", "adaptation-field-data" },
    { C_ENUM(GST_MTS_DESC_DVB_SERVICE_IDENTIFIER), "GST_MTS_DESC_DVB_SERVICE_IDENTIFIER", "service-identifier" },
    { C_ENUM(GST_MTS_DESC_DVB_SERVICE_AVAILABILITY), "GST_MTS_DESC_DVB_SERVICE_AVAILABILITY", "service-availability" },
    { C_ENUM(GST_MTS_DESC_DVB_DEFAULT_AUTHORITY), "GST_MTS_DESC_DVB_DEFAULT_AUTHORITY", "default-authority" },
    { C_ENUM(GST_MTS_DESC_DVB_RELATED_CONTENT), "GST_MTS_DESC_DVB_RELATED_CONTENT", "related-content" },
    { C_ENUM(GST_MTS_DESC_DVB_TVA_ID), "GST_MTS_DESC_DVB_TVA_ID", "tva-id" },
    { C_ENUM(GST_MTS_DESC_DVB_CONTENT_IDENTIFIER), "GST_MTS_DESC_DVB_CONTENT_IDENTIFIER", "content-identifier" },
    { C_ENUM(GST_MTS_DESC_DVB_TIMESLICE_FEC_IDENTIFIER), "GST_MTS_DESC_DVB_TIMESLICE_FEC_IDENTIFIER", "timeslice-fec-identifier" },
    { C_ENUM(GST_MTS_DESC_DVB_ECM_REPETITION_RATE), "GST_MTS_DESC_DVB_ECM_REPETITION_RATE", "ecm-repetition-rate" },
    { C_ENUM(GST_MTS_DESC_DVB_S2_SATELLITE_DELIVERY_SYSTEM), "GST_MTS_DESC_DVB_S2_SATELLITE_DELIVERY_SYSTEM", "s2-satellite-delivery-system" },
    { C_ENUM(GST_MTS_DESC_DVB_ENHANCED_AC3), "GST_MTS_DESC_DVB_ENHANCED_AC3", "enhanced-ac3" },
    { C_ENUM(GST_MTS_DESC_DVB_DTS), "GST_MTS_DESC_DVB_DTS", "dts" },
    { C_ENUM(GST_MTS_DESC_DVB_AAC), "GST_MTS_DESC_DVB_AAC", "aac" },
    { C_ENUM(GST_MTS_DESC_DVB_XAIT_LOCATION), "GST_MTS_DESC_DVB_XAIT_LOCATION", "xait-location" },
    { C_ENUM(GST_MTS_DESC_DVB_FTA_CONTENT_MANAGEMENT), "GST_MTS_DESC_DVB_FTA_CONTENT_MANAGEMENT", "fta-content-management" },
    { C_ENUM(GST_MTS_DESC_DVB_EXTENSION), "GST_MTS_DESC_DVB_EXTENSION", "extension" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsDVBDescriptorType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_dvb_extended_descriptor_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_DESC_EXT_DVB_IMAGE_ICON), "GST_MTS_DESC_EXT_DVB_IMAGE_ICON", "image-icon" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_CPCM_DELIVERY_SIGNALLING), "GST_MTS_DESC_EXT_DVB_CPCM_DELIVERY_SIGNALLING", "cpcm-delivery-signalling" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_CP), "GST_MTS_DESC_EXT_DVB_CP", "cp" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_CP_IDENTIFIER), "GST_MTS_DESC_EXT_DVB_CP_IDENTIFIER", "cp-identifier" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_T2_DELIVERY_SYSTEM), "GST_MTS_DESC_EXT_DVB_T2_DELIVERY_SYSTEM", "t2-delivery-system" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_SH_DELIVERY_SYSTEM), "GST_MTS_DESC_EXT_DVB_SH_DELIVERY_SYSTEM", "sh-delivery-system" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_SUPPLEMENTARY_AUDIO), "GST_MTS_DESC_EXT_DVB_SUPPLEMENTARY_AUDIO", "supplementary-audio" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_NETWORK_CHANGE_NOTIFY), "GST_MTS_DESC_EXT_DVB_NETWORK_CHANGE_NOTIFY", "network-change-notify" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_MESSAGE), "GST_MTS_DESC_EXT_DVB_MESSAGE", "message" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_TARGET_REGION), "GST_MTS_DESC_EXT_DVB_TARGET_REGION", "target-region" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_TARGET_REGION_NAME), "GST_MTS_DESC_EXT_DVB_TARGET_REGION_NAME", "target-region-name" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_SERVICE_RELOCATED), "GST_MTS_DESC_EXT_DVB_SERVICE_RELOCATED", "service-relocated" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_XAIT_PID), "GST_MTS_DESC_EXT_DVB_XAIT_PID", "xait-pid" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_C2_DELIVERY_SYSTEM), "GST_MTS_DESC_EXT_DVB_C2_DELIVERY_SYSTEM", "c2-delivery-system" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_DTS_HD_AUDIO_STREAM), "GST_MTS_DESC_EXT_DVB_DTS_HD_AUDIO_STREAM", "dts-hd-audio-stream" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_DTS_NEUTRAL), "GST_MTS_DESC_EXT_DVB_DTS_NEUTRAL", "dts-neutral" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_VIDEO_DEPTH_RANGE), "GST_MTS_DESC_EXT_DVB_VIDEO_DEPTH_RANGE", "video-depth-range" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_T2MI), "GST_MTS_DESC_EXT_DVB_T2MI", "t2mi" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_URI_LINKAGE), "GST_MTS_DESC_EXT_DVB_URI_LINKAGE", "uri-linkage" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_AC4), "GST_MTS_DESC_EXT_DVB_AC4", "ac4" },
    { C_ENUM(GST_MTS_DESC_EXT_DVB_AUDIO_PRESELECTION), "GST_MTS_DESC_EXT_DVB_AUDIO_PRESELECTION", "audio-preselection" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsDVBExtendedDescriptorType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_modulation_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_MODULATION_QPSK), "GST_MPEGTS_MODULATION_QPSK", "qpsk" },
    { C_ENUM(GST_MPEGTS_MODULATION_QAM_16), "GST_MPEGTS_MODULATION_QAM_16", "qam-16" },
    { C_ENUM(GST_MPEGTS_MODULATION_QAM_32), "GST_MPEGTS_MODULATION_QAM_32", "qam-32" },
    { C_ENUM(GST_MPEGTS_MODULATION_QAM_64), "GST_MPEGTS_MODULATION_QAM_64", "qam-64" },
    { C_ENUM(GST_MPEGTS_MODULATION_QAM_128), "GST_MPEGTS_MODULATION_QAM_128", "qam-128" },
    { C_ENUM(GST_MPEGTS_MODULATION_QAM_256), "GST_MPEGTS_MODULATION_QAM_256", "qam-256" },
    { C_ENUM(GST_MPEGTS_MODULATION_QAM_AUTO), "GST_MPEGTS_MODULATION_QAM_AUTO", "qam-auto" },
    { C_ENUM(GST_MPEGTS_MODULATION_VSB_8), "GST_MPEGTS_MODULATION_VSB_8", "vsb-8" },
    { C_ENUM(GST_MPEGTS_MODULATION_VSB_16), "GST_MPEGTS_MODULATION_VSB_16", "vsb-16" },
    { C_ENUM(GST_MPEGTS_MODULATION_PSK_8), "GST_MPEGTS_MODULATION_PSK_8", "psk-8" },
    { C_ENUM(GST_MPEGTS_MODULATION_APSK_16), "GST_MPEGTS_MODULATION_APSK_16", "apsk-16" },
    { C_ENUM(GST_MPEGTS_MODULATION_APSK_32), "GST_MPEGTS_MODULATION_APSK_32", "apsk-32" },
    { C_ENUM(GST_MPEGTS_MODULATION_DQPSK), "GST_MPEGTS_MODULATION_DQPSK", "dqpsk" },
    { C_ENUM(GST_MPEGTS_MODULATION_QAM_4_NR_), "GST_MPEGTS_MODULATION_QAM_4_NR_", "qam-4-nr-" },
    { C_ENUM(GST_MPEGTS_MODULATION_NONE), "GST_MPEGTS_MODULATION_NONE", "none" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsModulationType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_dvb_code_rate_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_FEC_NONE), "GST_MPEGTS_FEC_NONE", "none" },
    { C_ENUM(GST_MPEGTS_FEC_1_2), "GST_MPEGTS_FEC_1_2", "1-2" },
    { C_ENUM(GST_MPEGTS_FEC_2_3), "GST_MPEGTS_FEC_2_3", "2-3" },
    { C_ENUM(GST_MPEGTS_FEC_3_4), "GST_MPEGTS_FEC_3_4", "3-4" },
    { C_ENUM(GST_MPEGTS_FEC_4_5), "GST_MPEGTS_FEC_4_5", "4-5" },
    { C_ENUM(GST_MPEGTS_FEC_5_6), "GST_MPEGTS_FEC_5_6", "5-6" },
    { C_ENUM(GST_MPEGTS_FEC_6_7), "GST_MPEGTS_FEC_6_7", "6-7" },
    { C_ENUM(GST_MPEGTS_FEC_7_8), "GST_MPEGTS_FEC_7_8", "7-8" },
    { C_ENUM(GST_MPEGTS_FEC_8_9), "GST_MPEGTS_FEC_8_9", "8-9" },
    { C_ENUM(GST_MPEGTS_FEC_AUTO), "GST_MPEGTS_FEC_AUTO", "auto" },
    { C_ENUM(GST_MPEGTS_FEC_3_5), "GST_MPEGTS_FEC_3_5", "3-5" },
    { C_ENUM(GST_MPEGTS_FEC_9_10), "GST_MPEGTS_FEC_9_10", "9-10" },
    { C_ENUM(GST_MPEGTS_FEC_2_5), "GST_MPEGTS_FEC_2_5", "2-5" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsDVBCodeRate"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_satellite_rolloff_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_ROLLOFF_35), "GST_MPEGTS_ROLLOFF_35", "35" },
    { C_ENUM(GST_MPEGTS_ROLLOFF_20), "GST_MPEGTS_ROLLOFF_20", "20" },
    { C_ENUM(GST_MPEGTS_ROLLOFF_25), "GST_MPEGTS_ROLLOFF_25", "25" },
    { C_ENUM(GST_MPEGTS_ROLLOFF_RESERVED), "GST_MPEGTS_ROLLOFF_RESERVED", "reserved" },
    { C_ENUM(GST_MPEGTS_ROLLOFF_AUTO), "GST_MPEGTS_ROLLOFF_AUTO", "auto" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsSatelliteRolloff"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_satellite_polarization_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_POLARIZATION_LINEAR_HORIZONTAL), "GST_MPEGTS_POLARIZATION_LINEAR_HORIZONTAL", "linear-horizontal" },
    { C_ENUM(GST_MPEGTS_POLARIZATION_LINEAR_VERTICAL), "GST_MPEGTS_POLARIZATION_LINEAR_VERTICAL", "linear-vertical" },
    { C_ENUM(GST_MPEGTS_POLARIZATION_CIRCULAR_LEFT), "GST_MPEGTS_POLARIZATION_CIRCULAR_LEFT", "circular-left" },
    { C_ENUM(GST_MPEGTS_POLARIZATION_CIRCULAR_RIGHT), "GST_MPEGTS_POLARIZATION_CIRCULAR_RIGHT", "circular-right" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsSatellitePolarizationType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_cable_outer_fec_scheme_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_CABLE_OUTER_FEC_UNDEFINED), "GST_MPEGTS_CABLE_OUTER_FEC_UNDEFINED", "undefined" },
    { C_ENUM(GST_MPEGTS_CABLE_OUTER_FEC_NONE), "GST_MPEGTS_CABLE_OUTER_FEC_NONE", "none" },
    { C_ENUM(GST_MPEGTS_CABLE_OUTER_FEC_RS_204_188), "GST_MPEGTS_CABLE_OUTER_FEC_RS_204_188", "rs-204-188" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsCableOuterFECScheme"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_dvb_service_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_DVB_SERVICE_RESERVED_00), "GST_DVB_SERVICE_RESERVED_00", "reserved-00" },
    { C_ENUM(GST_DVB_SERVICE_DIGITAL_TELEVISION), "GST_DVB_SERVICE_DIGITAL_TELEVISION", "digital-television" },
    { C_ENUM(GST_DVB_SERVICE_DIGITAL_RADIO_SOUND), "GST_DVB_SERVICE_DIGITAL_RADIO_SOUND", "digital-radio-sound" },
    { C_ENUM(GST_DVB_SERVICE_TELETEXT), "GST_DVB_SERVICE_TELETEXT", "teletext" },
    { C_ENUM(GST_DVB_SERVICE_NVOD_REFERENCE), "GST_DVB_SERVICE_NVOD_REFERENCE", "nvod-reference" },
    { C_ENUM(GST_DVB_SERVICE_NVOD_TIME_SHIFTED), "GST_DVB_SERVICE_NVOD_TIME_SHIFTED", "nvod-time-shifted" },
    { C_ENUM(GST_DVB_SERVICE_MOSAIC), "GST_DVB_SERVICE_MOSAIC", "mosaic" },
    { C_ENUM(GST_DVB_SERVICE_FM_RADIO), "GST_DVB_SERVICE_FM_RADIO", "fm-radio" },
    { C_ENUM(GST_DVB_SERVICE_DVB_SRM), "GST_DVB_SERVICE_DVB_SRM", "dvb-srm" },
    { C_ENUM(GST_DVB_SERVICE_RESERVED_09), "GST_DVB_SERVICE_RESERVED_09", "reserved-09" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_DIGITAL_RADIO_SOUND), "GST_DVB_SERVICE_ADVANCED_CODEC_DIGITAL_RADIO_SOUND", "advanced-codec-digital-radio-sound" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_MOSAIC), "GST_DVB_SERVICE_ADVANCED_CODEC_MOSAIC", "advanced-codec-mosaic" },
    { C_ENUM(GST_DVB_SERVICE_DATA_BROADCAST), "GST_DVB_SERVICE_DATA_BROADCAST", "data-broadcast" },
    { C_ENUM(GST_DVB_SERVICE_RESERVED_0D_COMMON_INTERFACE), "GST_DVB_SERVICE_RESERVED_0D_COMMON_INTERFACE", "reserved-0d-common-interface" },
    { C_ENUM(GST_DVB_SERVICE_RCS_MAP), "GST_DVB_SERVICE_RCS_MAP", "rcs-map" },
    { C_ENUM(GST_DVB_SERVICE_RCS_FLS), "GST_DVB_SERVICE_RCS_FLS", "rcs-fls" },
    { C_ENUM(GST_DVB_SERVICE_DVB_MHP), "GST_DVB_SERVICE_DVB_MHP", "dvb-mhp" },
    { C_ENUM(GST_DVB_SERVICE_MPEG2_HD_DIGITAL_TELEVISION), "GST_DVB_SERVICE_MPEG2_HD_DIGITAL_TELEVISION", "mpeg2-hd-digital-television" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_SD_DIGITAL_TELEVISION), "GST_DVB_SERVICE_ADVANCED_CODEC_SD_DIGITAL_TELEVISION", "advanced-codec-sd-digital-television" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_SD_NVOD_TIME_SHIFTED), "GST_DVB_SERVICE_ADVANCED_CODEC_SD_NVOD_TIME_SHIFTED", "advanced-codec-sd-nvod-time-shifted" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_SD_NVOD_REFERENCE), "GST_DVB_SERVICE_ADVANCED_CODEC_SD_NVOD_REFERENCE", "advanced-codec-sd-nvod-reference" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_HD_DIGITAL_TELEVISION), "GST_DVB_SERVICE_ADVANCED_CODEC_HD_DIGITAL_TELEVISION", "advanced-codec-hd-digital-television" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_HD_NVOD_TIME_SHIFTED), "GST_DVB_SERVICE_ADVANCED_CODEC_HD_NVOD_TIME_SHIFTED", "advanced-codec-hd-nvod-time-shifted" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_HD_NVOD_REFERENCE), "GST_DVB_SERVICE_ADVANCED_CODEC_HD_NVOD_REFERENCE", "advanced-codec-hd-nvod-reference" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_STEREO_HD_DIGITAL_TELEVISION), "GST_DVB_SERVICE_ADVANCED_CODEC_STEREO_HD_DIGITAL_TELEVISION", "advanced-codec-stereo-hd-digital-television" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_STEREO_HD_NVOD_TIME_SHIFTED), "GST_DVB_SERVICE_ADVANCED_CODEC_STEREO_HD_NVOD_TIME_SHIFTED", "advanced-codec-stereo-hd-nvod-time-shifted" },
    { C_ENUM(GST_DVB_SERVICE_ADVANCED_CODEC_STEREO_HD_NVOD_REFERENCE), "GST_DVB_SERVICE_ADVANCED_CODEC_STEREO_HD_NVOD_REFERENCE", "advanced-codec-stereo-hd-nvod-reference" },
    { C_ENUM(GST_DVB_SERVICE_RESERVED_FF), "GST_DVB_SERVICE_RESERVED_FF", "reserved-ff" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsDVBServiceType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_dvb_linkage_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_RESERVED_00), "GST_MPEGTS_DVB_LINKAGE_RESERVED_00", "reserved-00" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_INFORMATION), "GST_MPEGTS_DVB_LINKAGE_INFORMATION", "information" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_EPG), "GST_MPEGTS_DVB_LINKAGE_EPG", "epg" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_CA_REPLACEMENT), "GST_MPEGTS_DVB_LINKAGE_CA_REPLACEMENT", "ca-replacement" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_TS_CONTAINING_COMPLETE_SI), "GST_MPEGTS_DVB_LINKAGE_TS_CONTAINING_COMPLETE_SI", "ts-containing-complete-si" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_SERVICE_REPLACEMENT), "GST_MPEGTS_DVB_LINKAGE_SERVICE_REPLACEMENT", "service-replacement" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_DATA_BROADCAST), "GST_MPEGTS_DVB_LINKAGE_DATA_BROADCAST", "data-broadcast" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_RCS_MAP), "GST_MPEGTS_DVB_LINKAGE_RCS_MAP", "rcs-map" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_MOBILE_HAND_OVER), "GST_MPEGTS_DVB_LINKAGE_MOBILE_HAND_OVER", "mobile-hand-over" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_SYSTEM_SOFTWARE_UPDATE), "GST_MPEGTS_DVB_LINKAGE_SYSTEM_SOFTWARE_UPDATE", "system-software-update" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_TS_CONTAINING_SSU), "GST_MPEGTS_DVB_LINKAGE_TS_CONTAINING_SSU", "ts-containing-ssu" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_IP_MAC_NOTIFICATION), "GST_MPEGTS_DVB_LINKAGE_IP_MAC_NOTIFICATION", "ip-mac-notification" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_TS_CONTAINING_INT), "GST_MPEGTS_DVB_LINKAGE_TS_CONTAINING_INT", "ts-containing-int" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_EVENT), "GST_MPEGTS_DVB_LINKAGE_EVENT", "event" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_EXTENDED_EVENT), "GST_MPEGTS_DVB_LINKAGE_EXTENDED_EVENT", "extended-event" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsDVBLinkageType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_dvb_linkage_hand_over_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_HAND_OVER_RESERVED), "GST_MPEGTS_DVB_LINKAGE_HAND_OVER_RESERVED", "reserved" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_HAND_OVER_IDENTICAL), "GST_MPEGTS_DVB_LINKAGE_HAND_OVER_IDENTICAL", "identical" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_HAND_OVER_LOCAL_VARIATION), "GST_MPEGTS_DVB_LINKAGE_HAND_OVER_LOCAL_VARIATION", "local-variation" },
    { C_ENUM(GST_MPEGTS_DVB_LINKAGE_HAND_OVER_ASSOCIATED), "GST_MPEGTS_DVB_LINKAGE_HAND_OVER_ASSOCIATED", "associated" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsDVBLinkageHandOverType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_component_stream_content_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_STREAM_CONTENT_MPEG2_VIDEO), "GST_MPEGTS_STREAM_CONTENT_MPEG2_VIDEO", "mpeg2-video" },
    { C_ENUM(GST_MPEGTS_STREAM_CONTENT_MPEG1_LAYER2_AUDIO), "GST_MPEGTS_STREAM_CONTENT_MPEG1_LAYER2_AUDIO", "mpeg1-layer2-audio" },
    { C_ENUM(GST_MPEGTS_STREAM_CONTENT_TELETEXT_OR_SUBTITLE), "GST_MPEGTS_STREAM_CONTENT_TELETEXT_OR_SUBTITLE", "teletext-or-subtitle" },
    { C_ENUM(GST_MPEGTS_STREAM_CONTENT_AC_3), "GST_MPEGTS_STREAM_CONTENT_AC_3", "ac-3" },
    { C_ENUM(GST_MPEGTS_STREAM_CONTENT_AVC), "GST_MPEGTS_STREAM_CONTENT_AVC", "avc" },
    { C_ENUM(GST_MPEGTS_STREAM_CONTENT_AAC), "GST_MPEGTS_STREAM_CONTENT_AAC", "aac" },
    { C_ENUM(GST_MPEGTS_STREAM_CONTENT_DTS), "GST_MPEGTS_STREAM_CONTENT_DTS", "dts" },
    { C_ENUM(GST_MPEGTS_STREAM_CONTENT_SRM_CPCM), "GST_MPEGTS_STREAM_CONTENT_SRM_CPCM", "srm-cpcm" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsComponentStreamContent"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_content_nibble_hi_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_CONTENT_MOVIE_DRAMA), "GST_MPEGTS_CONTENT_MOVIE_DRAMA", "movie-drama" },
    { C_ENUM(GST_MPEGTS_CONTENT_NEWS_CURRENT_AFFAIRS), "GST_MPEGTS_CONTENT_NEWS_CURRENT_AFFAIRS", "news-current-affairs" },
    { C_ENUM(GST_MPEGTS_CONTENT_SHOW_GAME_SHOW), "GST_MPEGTS_CONTENT_SHOW_GAME_SHOW", "show-game-show" },
    { C_ENUM(GST_MPEGTS_CONTENT_SPORTS), "GST_MPEGTS_CONTENT_SPORTS", "sports" },
    { C_ENUM(GST_MPEGTS_CONTENT_CHILDREN_YOUTH_PROGRAM), "GST_MPEGTS_CONTENT_CHILDREN_YOUTH_PROGRAM", "children-youth-program" },
    { C_ENUM(GST_MPEGTS_CONTENT_MUSIC_BALLET_DANCE), "GST_MPEGTS_CONTENT_MUSIC_BALLET_DANCE", "music-ballet-dance" },
    { C_ENUM(GST_MPEGTS_CONTENT_ARTS_CULTURE), "GST_MPEGTS_CONTENT_ARTS_CULTURE", "arts-culture" },
    { C_ENUM(GST_MPEGTS_CONTENT_SOCIAL_POLITICAL_ECONOMICS), "GST_MPEGTS_CONTENT_SOCIAL_POLITICAL_ECONOMICS", "social-political-economics" },
    { C_ENUM(GST_MPEGTS_CONTENT_EDUCATION_SCIENCE_FACTUAL), "GST_MPEGTS_CONTENT_EDUCATION_SCIENCE_FACTUAL", "education-science-factual" },
    { C_ENUM(GST_MPEGTS_CONTENT_LEISURE_HOBBIES), "GST_MPEGTS_CONTENT_LEISURE_HOBBIES", "leisure-hobbies" },
    { C_ENUM(GST_MPEGTS_CONTENT_SPECIAL_CHARACTERISTICS), "GST_MPEGTS_CONTENT_SPECIAL_CHARACTERISTICS", "special-characteristics" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsContentNibbleHi"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_dvb_teletext_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(INITIAL_PAGE), "INITIAL_PAGE", "initial-page" },
    { C_ENUM(SUBTITLE_PAGE), "SUBTITLE_PAGE", "subtitle-page" },
    { C_ENUM(ADDITIONAL_INFO_PAGE), "ADDITIONAL_INFO_PAGE", "additional-info-page" },
    { C_ENUM(PROGRAMME_SCHEDULE_PAGE), "PROGRAMME_SCHEDULE_PAGE", "programme-schedule-page" },
    { C_ENUM(HEARING_IMPAIRED_PAGE), "HEARING_IMPAIRED_PAGE", "hearing-impaired-page" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsDVBTeletextType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_terrestrial_transmission_mode_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_TRANSMISSION_MODE_2K), "GST_MPEGTS_TRANSMISSION_MODE_2K", "2k" },
    { C_ENUM(GST_MPEGTS_TRANSMISSION_MODE_8K), "GST_MPEGTS_TRANSMISSION_MODE_8K", "8k" },
    { C_ENUM(GST_MPEGTS_TRANSMISSION_MODE_AUTO), "GST_MPEGTS_TRANSMISSION_MODE_AUTO", "auto" },
    { C_ENUM(GST_MPEGTS_TRANSMISSION_MODE_4K), "GST_MPEGTS_TRANSMISSION_MODE_4K", "4k" },
    { C_ENUM(GST_MPEGTS_TRANSMISSION_MODE_1K), "GST_MPEGTS_TRANSMISSION_MODE_1K", "1k" },
    { C_ENUM(GST_MPEGTS_TRANSMISSION_MODE_16K), "GST_MPEGTS_TRANSMISSION_MODE_16K", "16k" },
    { C_ENUM(GST_MPEGTS_TRANSMISSION_MODE_32K), "GST_MPEGTS_TRANSMISSION_MODE_32K", "32k" },
    { C_ENUM(GST_MPEGTS_TRANSMISSION_MODE_C1), "GST_MPEGTS_TRANSMISSION_MODE_C1", "c1" },
    { C_ENUM(GST_MPEGTS_TRANSMISSION_MODE_C3780), "GST_MPEGTS_TRANSMISSION_MODE_C3780", "c3780" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsTerrestrialTransmissionMode"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_terrestrial_guard_interval_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_1_32), "GST_MPEGTS_GUARD_INTERVAL_1_32", "1-32" },
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_1_16), "GST_MPEGTS_GUARD_INTERVAL_1_16", "1-16" },
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_1_8), "GST_MPEGTS_GUARD_INTERVAL_1_8", "1-8" },
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_1_4), "GST_MPEGTS_GUARD_INTERVAL_1_4", "1-4" },
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_AUTO), "GST_MPEGTS_GUARD_INTERVAL_AUTO", "auto" },
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_1_128), "GST_MPEGTS_GUARD_INTERVAL_1_128", "1-128" },
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_19_128), "GST_MPEGTS_GUARD_INTERVAL_19_128", "19-128" },
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_19_256), "GST_MPEGTS_GUARD_INTERVAL_19_256", "19-256" },
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_PN420), "GST_MPEGTS_GUARD_INTERVAL_PN420", "pn420" },
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_PN595), "GST_MPEGTS_GUARD_INTERVAL_PN595", "pn595" },
    { C_ENUM(GST_MPEGTS_GUARD_INTERVAL_PN945), "GST_MPEGTS_GUARD_INTERVAL_PN945", "pn945" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsTerrestrialGuardInterval"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_terrestrial_hierarchy_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_HIERARCHY_NONE), "GST_MPEGTS_HIERARCHY_NONE", "none" },
    { C_ENUM(GST_MPEGTS_HIERARCHY_1), "GST_MPEGTS_HIERARCHY_1", "1" },
    { C_ENUM(GST_MPEGTS_HIERARCHY_2), "GST_MPEGTS_HIERARCHY_2", "2" },
    { C_ENUM(GST_MPEGTS_HIERARCHY_4), "GST_MPEGTS_HIERARCHY_4", "4" },
    { C_ENUM(GST_MPEGTS_HIERARCHY_AUTO), "GST_MPEGTS_HIERARCHY_AUTO", "auto" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsTerrestrialHierarchy"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_dvb_scrambling_mode_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_DVB_SCRAMBLING_MODE_RESERVED), "GST_MPEGTS_DVB_SCRAMBLING_MODE_RESERVED", "reserved" },
    { C_ENUM(GST_MPEGTS_DVB_SCRAMBLING_MODE_CSA1), "GST_MPEGTS_DVB_SCRAMBLING_MODE_CSA1", "csa1" },
    { C_ENUM(GST_MPEGTS_DVB_SCRAMBLING_MODE_CSA2), "GST_MPEGTS_DVB_SCRAMBLING_MODE_CSA2", "csa2" },
    { C_ENUM(GST_MPEGTS_DVB_SCRAMBLING_MODE_CSA3_STANDARD), "GST_MPEGTS_DVB_SCRAMBLING_MODE_CSA3_STANDARD", "csa3-standard" },
    { C_ENUM(GST_MPEGTS_DVB_SCRAMBLING_MODE_CSA3_MINIMAL_ENHANCED), "GST_MPEGTS_DVB_SCRAMBLING_MODE_CSA3_MINIMAL_ENHANCED", "csa3-minimal-enhanced" },
    { C_ENUM(GST_MPEGTS_DVB_SCRAMBLING_MODE_CSA3_FULL_ENHANCED), "GST_MPEGTS_DVB_SCRAMBLING_MODE_CSA3_FULL_ENHANCED", "csa3-full-enhanced" },
    { C_ENUM(GST_MPEGTS_DVB_SCRAMBLING_MODE_CISSA), "GST_MPEGTS_DVB_SCRAMBLING_MODE_CISSA", "cissa" },
    { C_ENUM(GST_MPEGTS_DVB_SCRAMBLING_MODE_ATIS_0), "GST_MPEGTS_DVB_SCRAMBLING_MODE_ATIS_0", "atis-0" },
    { C_ENUM(GST_MPEGTS_DVB_SCRAMBLING_MODE_ATIS_F), "GST_MPEGTS_DVB_SCRAMBLING_MODE_ATIS_F", "atis-f" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsDVBScramblingModeType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

/* enumerations from "gst-dvb-section.h" */

GType
gst_mpegts_section_dvb_table_id_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_TABLE_ID_NETWORK_INFORMATION_ACTUAL_NETWORK), "GST_MTS_TABLE_ID_NETWORK_INFORMATION_ACTUAL_NETWORK", "network-information-actual-network" },
    { C_ENUM(GST_MTS_TABLE_ID_NETWORK_INFORMATION_OTHER_NETWORK), "GST_MTS_TABLE_ID_NETWORK_INFORMATION_OTHER_NETWORK", "network-information-other-network" },
    { C_ENUM(GST_MTS_TABLE_ID_SERVICE_DESCRIPTION_ACTUAL_TS), "GST_MTS_TABLE_ID_SERVICE_DESCRIPTION_ACTUAL_TS", "service-description-actual-ts" },
    { C_ENUM(GST_MTS_TABLE_ID_SERVICE_DESCRIPTION_OTHER_TS), "GST_MTS_TABLE_ID_SERVICE_DESCRIPTION_OTHER_TS", "service-description-other-ts" },
    { C_ENUM(GST_MTS_TABLE_ID_BOUQUET_ASSOCIATION), "GST_MTS_TABLE_ID_BOUQUET_ASSOCIATION", "bouquet-association" },
    { C_ENUM(GST_MTS_TABLE_ID_UPDATE_NOTIFICATION), "GST_MTS_TABLE_ID_UPDATE_NOTIFICATION", "update-notification" },
    { C_ENUM(GST_MTS_TABLE_ID_DOWNLOADABLE_FONT_INFO), "GST_MTS_TABLE_ID_DOWNLOADABLE_FONT_INFO", "downloadable-font-info" },
    { C_ENUM(GST_MTS_TABLE_ID_EVENT_INFORMATION_ACTUAL_TS_PRESENT), "GST_MTS_TABLE_ID_EVENT_INFORMATION_ACTUAL_TS_PRESENT", "event-information-actual-ts-present" },
    { C_ENUM(GST_MTS_TABLE_ID_EVENT_INFORMATION_OTHER_TS_PRESENT), "GST_MTS_TABLE_ID_EVENT_INFORMATION_OTHER_TS_PRESENT", "event-information-other-ts-present" },
    { C_ENUM(GST_MTS_TABLE_ID_EVENT_INFORMATION_ACTUAL_TS_SCHEDULE_1), "GST_MTS_TABLE_ID_EVENT_INFORMATION_ACTUAL_TS_SCHEDULE_1", "event-information-actual-ts-schedule-1" },
    { C_ENUM(GST_MTS_TABLE_ID_EVENT_INFORMATION_ACTUAL_TS_SCHEDULE_N), "GST_MTS_TABLE_ID_EVENT_INFORMATION_ACTUAL_TS_SCHEDULE_N", "event-information-actual-ts-schedule-n" },
    { C_ENUM(GST_MTS_TABLE_ID_EVENT_INFORMATION_OTHER_TS_SCHEDULE_1), "GST_MTS_TABLE_ID_EVENT_INFORMATION_OTHER_TS_SCHEDULE_1", "event-information-other-ts-schedule-1" },
    { C_ENUM(GST_MTS_TABLE_ID_EVENT_INFORMATION_OTHER_TS_SCHEDULE_N), "GST_MTS_TABLE_ID_EVENT_INFORMATION_OTHER_TS_SCHEDULE_N", "event-information-other-ts-schedule-n" },
    { C_ENUM(GST_MTS_TABLE_ID_TIME_DATE), "GST_MTS_TABLE_ID_TIME_DATE", "time-date" },
    { C_ENUM(GST_MTS_TABLE_ID_RUNNING_STATUS), "GST_MTS_TABLE_ID_RUNNING_STATUS", "running-status" },
    { C_ENUM(GST_MTS_TABLE_ID_STUFFING), "GST_MTS_TABLE_ID_STUFFING", "stuffing" },
    { C_ENUM(GST_MTS_TABLE_ID_TIME_OFFSET), "GST_MTS_TABLE_ID_TIME_OFFSET", "time-offset" },
    { C_ENUM(GST_MTS_TABLE_ID_APPLICATION_INFORMATION_TABLE), "GST_MTS_TABLE_ID_APPLICATION_INFORMATION_TABLE", "application-information-table" },
    { C_ENUM(GST_MTS_TABLE_ID_CONTAINER), "GST_MTS_TABLE_ID_CONTAINER", "container" },
    { C_ENUM(GST_MTS_TABLE_ID_RELATED_CONTENT), "GST_MTS_TABLE_ID_RELATED_CONTENT", "related-content" },
    { C_ENUM(GST_MTS_TABLE_ID_CONTENT_IDENTIFIER), "GST_MTS_TABLE_ID_CONTENT_IDENTIFIER", "content-identifier" },
    { C_ENUM(GST_MTS_TABLE_ID_MPE_FEC), "GST_MTS_TABLE_ID_MPE_FEC", "mpe-fec" },
    { C_ENUM(GST_MTS_TABLE_ID_RESOLUTION_NOTIFICATION), "GST_MTS_TABLE_ID_RESOLUTION_NOTIFICATION", "resolution-notification" },
    { C_ENUM(GST_MTS_TABLE_ID_MPE_IFEC), "GST_MTS_TABLE_ID_MPE_IFEC", "mpe-ifec" },
    { C_ENUM(GST_MTS_TABLE_ID_PROTECTION_MESSAGE), "GST_MTS_TABLE_ID_PROTECTION_MESSAGE", "protection-message" },
    { C_ENUM(GST_MTS_TABLE_ID_DISCONTINUITY_INFORMATION), "GST_MTS_TABLE_ID_DISCONTINUITY_INFORMATION", "discontinuity-information" },
    { C_ENUM(GST_MTS_TABLE_ID_SELECTION_INFORMATION), "GST_MTS_TABLE_ID_SELECTION_INFORMATION", "selection-information" },
    { C_ENUM(GST_MTS_TABLE_ID_CA_MESSAGE_ECM_0), "GST_MTS_TABLE_ID_CA_MESSAGE_ECM_0", "ca-message-ecm-0" },
    { C_ENUM(GST_MTS_TABLE_ID_CA_MESSAGE_ECM_1), "GST_MTS_TABLE_ID_CA_MESSAGE_ECM_1", "ca-message-ecm-1" },
    { C_ENUM(GST_MTS_TABLE_ID_CA_MESSAGE_SYSTEM_PRIVATE_1), "GST_MTS_TABLE_ID_CA_MESSAGE_SYSTEM_PRIVATE_1", "ca-message-system-private-1" },
    { C_ENUM(GST_MTS_TABLE_ID_CA_MESSAGE_SYSTEM_PRIVATE_N), "GST_MTS_TABLE_ID_CA_MESSAGE_SYSTEM_PRIVATE_N", "ca-message-system-private-n" },
    { C_ENUM(GST_MTS_TABLE_ID_SCT), "GST_MTS_TABLE_ID_SCT", "sct" },
    { C_ENUM(GST_MTS_TABLE_ID_FCT), "GST_MTS_TABLE_ID_FCT", "fct" },
    { C_ENUM(GST_MTS_TABLE_ID_TCT), "GST_MTS_TABLE_ID_TCT", "tct" },
    { C_ENUM(GST_MTS_TABLE_ID_SPT), "GST_MTS_TABLE_ID_SPT", "spt" },
    { C_ENUM(GST_MTS_TABLE_ID_CMT), "GST_MTS_TABLE_ID_CMT", "cmt" },
    { C_ENUM(GST_MTS_TABLE_ID_TBTP), "GST_MTS_TABLE_ID_TBTP", "tbtp" },
    { C_ENUM(GST_MTS_TABLE_ID_PCR_PACKET_PAYLOAD), "GST_MTS_TABLE_ID_PCR_PACKET_PAYLOAD", "pcr-packet-payload" },
    { C_ENUM(GST_MTS_TABLE_ID_TRANSMISSION_MODE_SUPPORT_PAYLOAD), "GST_MTS_TABLE_ID_TRANSMISSION_MODE_SUPPORT_PAYLOAD", "transmission-mode-support-payload" },
    { C_ENUM(GST_MTS_TABLE_ID_TIM), "GST_MTS_TABLE_ID_TIM", "tim" },
    { C_ENUM(GST_MTS_TABLE_ID_LL_FEC_PARITY_DATA_TABLE), "GST_MTS_TABLE_ID_LL_FEC_PARITY_DATA_TABLE", "ll-fec-parity-data-table" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsSectionDVBTableID"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_running_status_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_RUNNING_STATUS_UNDEFINED), "GST_MPEGTS_RUNNING_STATUS_UNDEFINED", "undefined" },
    { C_ENUM(GST_MPEGTS_RUNNING_STATUS_NOT_RUNNING), "GST_MPEGTS_RUNNING_STATUS_NOT_RUNNING", "not-running" },
    { C_ENUM(GST_MPEGTS_RUNNING_STATUS_STARTS_IN_FEW_SECONDS), "GST_MPEGTS_RUNNING_STATUS_STARTS_IN_FEW_SECONDS", "starts-in-few-seconds" },
    { C_ENUM(GST_MPEGTS_RUNNING_STATUS_PAUSING), "GST_MPEGTS_RUNNING_STATUS_PAUSING", "pausing" },
    { C_ENUM(GST_MPEGTS_RUNNING_STATUS_RUNNING), "GST_MPEGTS_RUNNING_STATUS_RUNNING", "running" },
    { C_ENUM(GST_MPEGTS_RUNNING_STATUS_OFF_AIR), "GST_MPEGTS_RUNNING_STATUS_OFF_AIR", "off-air" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsRunningStatus"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

/* enumerations from "gst-hdmv-section.h" */

GType
gst_mpegts_hdmv_stream_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_LPCM), "GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_LPCM", "audio-lpcm" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_AC3), "GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_AC3", "audio-ac3" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_DTS), "GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_DTS", "audio-dts" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_AC3_TRUE_HD), "GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_AC3_TRUE_HD", "audio-ac3-true-hd" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_AC3_PLUS), "GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_AC3_PLUS", "audio-ac3-plus" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_DTS_HD), "GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_DTS_HD", "audio-dts-hd" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_DTS_HD_MASTER_AUDIO), "GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_DTS_HD_MASTER_AUDIO", "audio-dts-hd-master-audio" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_EAC3), "GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_EAC3", "audio-eac3" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_SUBPICTURE_PGS), "GST_MPEGTS_STREAM_TYPE_HDMV_SUBPICTURE_PGS", "subpicture-pgs" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_IGS), "GST_MPEGTS_STREAM_TYPE_HDMV_IGS", "igs" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_SUBTITLE), "GST_MPEGTS_STREAM_TYPE_HDMV_SUBTITLE", "subtitle" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_AC3_PLUS_SECONDARY), "GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_AC3_PLUS_SECONDARY", "audio-ac3-plus-secondary" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_DTS_HD_SECONDARY), "GST_MPEGTS_STREAM_TYPE_HDMV_AUDIO_DTS_HD_SECONDARY", "audio-dts-hd-secondary" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsHdmvStreamType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

/* enumerations from "gst-isdb-descriptor.h" */

GType
gst_mpegts_isdb_descriptor_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_DESC_ISDB_HIERARCHICAL_TRANSMISSION), "GST_MTS_DESC_ISDB_HIERARCHICAL_TRANSMISSION", "hierarchical-transmission" },
    { C_ENUM(GST_MTS_DESC_ISDB_DIGITAL_COPY_CONTROL), "GST_MTS_DESC_ISDB_DIGITAL_COPY_CONTROL", "digital-copy-control" },
    { C_ENUM(GST_MTS_DESC_ISDB_NETWORK_IDENTIFICATION), "GST_MTS_DESC_ISDB_NETWORK_IDENTIFICATION", "network-identification" },
    { C_ENUM(GST_MTS_DESC_ISDB_PARTIAL_TS_TIME), "GST_MTS_DESC_ISDB_PARTIAL_TS_TIME", "partial-ts-time" },
    { C_ENUM(GST_MTS_DESC_ISDB_AUDIO_COMPONENT), "GST_MTS_DESC_ISDB_AUDIO_COMPONENT", "audio-component" },
    { C_ENUM(GST_MTS_DESC_ISDB_HYPERLINK), "GST_MTS_DESC_ISDB_HYPERLINK", "hyperlink" },
    { C_ENUM(GST_MTS_DESC_ISDB_TARGET_REGION), "GST_MTS_DESC_ISDB_TARGET_REGION", "target-region" },
    { C_ENUM(GST_MTS_DESC_ISDB_DATA_CONTENT), "GST_MTS_DESC_ISDB_DATA_CONTENT", "data-content" },
    { C_ENUM(GST_MTS_DESC_ISDB_VIDEO_DECODE_CONTROL), "GST_MTS_DESC_ISDB_VIDEO_DECODE_CONTROL", "video-decode-control" },
    { C_ENUM(GST_MTS_DESC_ISDB_DOWNLOAD_CONTENT), "GST_MTS_DESC_ISDB_DOWNLOAD_CONTENT", "download-content" },
    { C_ENUM(GST_MTS_DESC_ISDB_CA_EMM_TS), "GST_MTS_DESC_ISDB_CA_EMM_TS", "ca-emm-ts" },
    { C_ENUM(GST_MTS_DESC_ISDB_CA_CONTRACT_INFORMATION), "GST_MTS_DESC_ISDB_CA_CONTRACT_INFORMATION", "ca-contract-information" },
    { C_ENUM(GST_MTS_DESC_ISDB_CA_SERVICE), "GST_MTS_DESC_ISDB_CA_SERVICE", "ca-service" },
    { C_ENUM(GST_MTS_DESC_ISDB_TS_INFORMATION), "GST_MTS_DESC_ISDB_TS_INFORMATION", "ts-information" },
    { C_ENUM(GST_MTS_DESC_ISDB_EXTENDED_BROADCASTER), "GST_MTS_DESC_ISDB_EXTENDED_BROADCASTER", "extended-broadcaster" },
    { C_ENUM(GST_MTS_DESC_ISDB_LOGO_TRANSMISSION), "GST_MTS_DESC_ISDB_LOGO_TRANSMISSION", "logo-transmission" },
    { C_ENUM(GST_MTS_DESC_ISDB_BASIC_LOCAL_EVENT), "GST_MTS_DESC_ISDB_BASIC_LOCAL_EVENT", "basic-local-event" },
    { C_ENUM(GST_MTS_DESC_ISDB_REFERENCE), "GST_MTS_DESC_ISDB_REFERENCE", "reference" },
    { C_ENUM(GST_MTS_DESC_ISDB_NODE_RELATION), "GST_MTS_DESC_ISDB_NODE_RELATION", "node-relation" },
    { C_ENUM(GST_MTS_DESC_ISDB_SHORT_NODE_INFORMATION), "GST_MTS_DESC_ISDB_SHORT_NODE_INFORMATION", "short-node-information" },
    { C_ENUM(GST_MTS_DESC_ISDB_STC_REFERENCE), "GST_MTS_DESC_ISDB_STC_REFERENCE", "stc-reference" },
    { C_ENUM(GST_MTS_DESC_ISDB_SERIES), "GST_MTS_DESC_ISDB_SERIES", "series" },
    { C_ENUM(GST_MTS_DESC_ISDB_EVENT_GROUP), "GST_MTS_DESC_ISDB_EVENT_GROUP", "event-group" },
    { C_ENUM(GST_MTS_DESC_ISDB_SI_PARAMETER), "GST_MTS_DESC_ISDB_SI_PARAMETER", "si-parameter" },
    { C_ENUM(GST_MTS_DESC_ISDB_BROADCASTER_NAME), "GST_MTS_DESC_ISDB_BROADCASTER_NAME", "broadcaster-name" },
    { C_ENUM(GST_MTS_DESC_ISDB_COMPONENT_GROUP), "GST_MTS_DESC_ISDB_COMPONENT_GROUP", "component-group" },
    { C_ENUM(GST_MTS_DESC_ISDB_SI_PRIME_TS), "GST_MTS_DESC_ISDB_SI_PRIME_TS", "si-prime-ts" },
    { C_ENUM(GST_MTS_DESC_ISDB_BOARD_INFORMATION), "GST_MTS_DESC_ISDB_BOARD_INFORMATION", "board-information" },
    { C_ENUM(GST_MTS_DESC_ISDB_LDT_LINKAGE), "GST_MTS_DESC_ISDB_LDT_LINKAGE", "ldt-linkage" },
    { C_ENUM(GST_MTS_DESC_ISDB_CONNECTED_TRANSMISSION), "GST_MTS_DESC_ISDB_CONNECTED_TRANSMISSION", "connected-transmission" },
    { C_ENUM(GST_MTS_DESC_ISDB_CONTENT_AVAILABILITY), "GST_MTS_DESC_ISDB_CONTENT_AVAILABILITY", "content-availability" },
    { C_ENUM(GST_MTS_DESC_ISDB_SERVICE_GROUP), "GST_MTS_DESC_ISDB_SERVICE_GROUP", "service-group" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsISDBDescriptorType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

/* enumerations from "gst-scte-section.h" */

GType
gst_mpegts_scte_stream_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SCTE_SUBTITLING), "GST_MPEGTS_STREAM_TYPE_SCTE_SUBTITLING", "subtitling" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SCTE_ISOCH_DATA), "GST_MPEGTS_STREAM_TYPE_SCTE_ISOCH_DATA", "isoch-data" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SCTE_SIT), "GST_MPEGTS_STREAM_TYPE_SCTE_SIT", "sit" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SCTE_DST_NRT), "GST_MPEGTS_STREAM_TYPE_SCTE_DST_NRT", "dst-nrt" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SCTE_DSMCC_DCB), "GST_MPEGTS_STREAM_TYPE_SCTE_DSMCC_DCB", "dsmcc-dcb" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SCTE_SIGNALING), "GST_MPEGTS_STREAM_TYPE_SCTE_SIGNALING", "signaling" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SCTE_SYNC_DATA), "GST_MPEGTS_STREAM_TYPE_SCTE_SYNC_DATA", "sync-data" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SCTE_ASYNC_DATA), "GST_MPEGTS_STREAM_TYPE_SCTE_ASYNC_DATA", "async-data" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsScteStreamType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_section_scte_table_id_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_TABLE_ID_SCTE_EAS), "GST_MTS_TABLE_ID_SCTE_EAS", "eas" },
    { C_ENUM(GST_MTS_TABLE_ID_SCTE_EBIF), "GST_MTS_TABLE_ID_SCTE_EBIF", "ebif" },
    { C_ENUM(GST_MTS_TABLE_ID_SCTE_RESERVED), "GST_MTS_TABLE_ID_SCTE_RESERVED", "reserved" },
    { C_ENUM(GST_MTS_TABLE_ID_SCTE_EISS), "GST_MTS_TABLE_ID_SCTE_EISS", "eiss" },
    { C_ENUM(GST_MTS_TABLE_ID_SCTE_DII), "GST_MTS_TABLE_ID_SCTE_DII", "dii" },
    { C_ENUM(GST_MTS_TABLE_ID_SCTE_DDB), "GST_MTS_TABLE_ID_SCTE_DDB", "ddb" },
    { C_ENUM(GST_MTS_TABLE_ID_SCTE_SPLICE), "GST_MTS_TABLE_ID_SCTE_SPLICE", "splice" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsSectionSCTETableID"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_scte_splice_descriptor_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_SCTE_DESC_AVAIL), "GST_MTS_SCTE_DESC_AVAIL", "avail" },
    { C_ENUM(GST_MTS_SCTE_DESC_DTMF), "GST_MTS_SCTE_DESC_DTMF", "dtmf" },
    { C_ENUM(GST_MTS_SCTE_DESC_SEGMENTATION), "GST_MTS_SCTE_DESC_SEGMENTATION", "segmentation" },
    { C_ENUM(GST_MTS_SCTE_DESC_TIME), "GST_MTS_SCTE_DESC_TIME", "time" },
    { C_ENUM(GST_MTS_SCTE_DESC_AUDIO), "GST_MTS_SCTE_DESC_AUDIO", "audio" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsSCTESpliceDescriptor"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_scte_splice_command_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_SCTE_SPLICE_COMMAND_NULL), "GST_MTS_SCTE_SPLICE_COMMAND_NULL", "null" },
    { C_ENUM(GST_MTS_SCTE_SPLICE_COMMAND_SCHEDULE), "GST_MTS_SCTE_SPLICE_COMMAND_SCHEDULE", "schedule" },
    { C_ENUM(GST_MTS_SCTE_SPLICE_COMMAND_INSERT), "GST_MTS_SCTE_SPLICE_COMMAND_INSERT", "insert" },
    { C_ENUM(GST_MTS_SCTE_SPLICE_COMMAND_TIME), "GST_MTS_SCTE_SPLICE_COMMAND_TIME", "time" },
    { C_ENUM(GST_MTS_SCTE_SPLICE_COMMAND_BANDWIDTH), "GST_MTS_SCTE_SPLICE_COMMAND_BANDWIDTH", "bandwidth" },
    { C_ENUM(GST_MTS_SCTE_SPLICE_COMMAND_PRIVATE), "GST_MTS_SCTE_SPLICE_COMMAND_PRIVATE", "private" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsSCTESpliceCommandType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

/* enumerations from "gstmpegtsdescriptor.h" */

GType
gst_mpegts_descriptor_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_DESC_RESERVED_00), "GST_MTS_DESC_RESERVED_00", "reserved-00" },
    { C_ENUM(GST_MTS_DESC_RESERVED_01), "GST_MTS_DESC_RESERVED_01", "reserved-01" },
    { C_ENUM(GST_MTS_DESC_VIDEO_STREAM), "GST_MTS_DESC_VIDEO_STREAM", "video-stream" },
    { C_ENUM(GST_MTS_DESC_AUDIO_STREAM), "GST_MTS_DESC_AUDIO_STREAM", "audio-stream" },
    { C_ENUM(GST_MTS_DESC_HIERARCHY), "GST_MTS_DESC_HIERARCHY", "hierarchy" },
    { C_ENUM(GST_MTS_DESC_REGISTRATION), "GST_MTS_DESC_REGISTRATION", "registration" },
    { C_ENUM(GST_MTS_DESC_DATA_STREAM_ALIGNMENT), "GST_MTS_DESC_DATA_STREAM_ALIGNMENT", "data-stream-alignment" },
    { C_ENUM(GST_MTS_DESC_TARGET_BACKGROUND_GRID), "GST_MTS_DESC_TARGET_BACKGROUND_GRID", "target-background-grid" },
    { C_ENUM(GST_MTS_DESC_VIDEO_WINDOW), "GST_MTS_DESC_VIDEO_WINDOW", "video-window" },
    { C_ENUM(GST_MTS_DESC_CA), "GST_MTS_DESC_CA", "ca" },
    { C_ENUM(GST_MTS_DESC_ISO_639_LANGUAGE), "GST_MTS_DESC_ISO_639_LANGUAGE", "iso-639-language" },
    { C_ENUM(GST_MTS_DESC_SYSTEM_CLOCK), "GST_MTS_DESC_SYSTEM_CLOCK", "system-clock" },
    { C_ENUM(GST_MTS_DESC_MULTIPLEX_BUFFER_UTILISATION), "GST_MTS_DESC_MULTIPLEX_BUFFER_UTILISATION", "multiplex-buffer-utilisation" },
    { C_ENUM(GST_MTS_DESC_COPYRIGHT), "GST_MTS_DESC_COPYRIGHT", "copyright" },
    { C_ENUM(GST_MTS_DESC_MAXIMUM_BITRATE), "GST_MTS_DESC_MAXIMUM_BITRATE", "maximum-bitrate" },
    { C_ENUM(GST_MTS_DESC_PRIVATE_DATA_INDICATOR), "GST_MTS_DESC_PRIVATE_DATA_INDICATOR", "private-data-indicator" },
    { C_ENUM(GST_MTS_DESC_SMOOTHING_BUFFER), "GST_MTS_DESC_SMOOTHING_BUFFER", "smoothing-buffer" },
    { C_ENUM(GST_MTS_DESC_STD), "GST_MTS_DESC_STD", "std" },
    { C_ENUM(GST_MTS_DESC_IBP), "GST_MTS_DESC_IBP", "ibp" },
    { C_ENUM(GST_MTS_DESC_DSMCC_CAROUSEL_IDENTIFIER), "GST_MTS_DESC_DSMCC_CAROUSEL_IDENTIFIER", "dsmcc-carousel-identifier" },
    { C_ENUM(GST_MTS_DESC_DSMCC_ASSOCIATION_TAG), "GST_MTS_DESC_DSMCC_ASSOCIATION_TAG", "dsmcc-association-tag" },
    { C_ENUM(GST_MTS_DESC_DSMCC_DEFERRED_ASSOCIATION_TAG), "GST_MTS_DESC_DSMCC_DEFERRED_ASSOCIATION_TAG", "dsmcc-deferred-association-tag" },
    { C_ENUM(GST_MTS_DESC_DSMCC_NPT_REFERENCE), "GST_MTS_DESC_DSMCC_NPT_REFERENCE", "dsmcc-npt-reference" },
    { C_ENUM(GST_MTS_DESC_DSMCC_NPT_ENDPOINT), "GST_MTS_DESC_DSMCC_NPT_ENDPOINT", "dsmcc-npt-endpoint" },
    { C_ENUM(GST_MTS_DESC_DSMCC_STREAM_MODE), "GST_MTS_DESC_DSMCC_STREAM_MODE", "dsmcc-stream-mode" },
    { C_ENUM(GST_MTS_DESC_DSMCC_STREAM_EVENT), "GST_MTS_DESC_DSMCC_STREAM_EVENT", "dsmcc-stream-event" },
    { C_ENUM(GST_MTS_DESC_MPEG4_VIDEO), "GST_MTS_DESC_MPEG4_VIDEO", "mpeg4-video" },
    { C_ENUM(GST_MTS_DESC_MPEG4_AUDIO), "GST_MTS_DESC_MPEG4_AUDIO", "mpeg4-audio" },
    { C_ENUM(GST_MTS_DESC_IOD), "GST_MTS_DESC_IOD", "iod" },
    { C_ENUM(GST_MTS_DESC_SL), "GST_MTS_DESC_SL", "sl" },
    { C_ENUM(GST_MTS_DESC_FMC), "GST_MTS_DESC_FMC", "fmc" },
    { C_ENUM(GST_MTS_DESC_EXTERNAL_ES_ID), "GST_MTS_DESC_EXTERNAL_ES_ID", "external-es-id" },
    { C_ENUM(GST_MTS_DESC_MUX_CODE), "GST_MTS_DESC_MUX_CODE", "mux-code" },
    { C_ENUM(GST_MTS_DESC_FMX_BUFFER_SIZE), "GST_MTS_DESC_FMX_BUFFER_SIZE", "fmx-buffer-size" },
    { C_ENUM(GST_MTS_DESC_MULTIPLEX_BUFFER), "GST_MTS_DESC_MULTIPLEX_BUFFER", "multiplex-buffer" },
    { C_ENUM(GST_MTS_DESC_CONTENT_LABELING), "GST_MTS_DESC_CONTENT_LABELING", "content-labeling" },
    { C_ENUM(GST_MTS_DESC_METADATA_POINTER), "GST_MTS_DESC_METADATA_POINTER", "metadata-pointer" },
    { C_ENUM(GST_MTS_DESC_METADATA), "GST_MTS_DESC_METADATA", "metadata" },
    { C_ENUM(GST_MTS_DESC_METADATA_STD), "GST_MTS_DESC_METADATA_STD", "metadata-std" },
    { C_ENUM(GST_MTS_DESC_AVC_VIDEO), "GST_MTS_DESC_AVC_VIDEO", "avc-video" },
    { C_ENUM(GST_MTS_DESC_IPMP), "GST_MTS_DESC_IPMP", "ipmp" },
    { C_ENUM(GST_MTS_DESC_AVC_TIMING_AND_HRD), "GST_MTS_DESC_AVC_TIMING_AND_HRD", "avc-timing-and-hrd" },
    { C_ENUM(GST_MTS_DESC_MPEG2_AAC_AUDIO), "GST_MTS_DESC_MPEG2_AAC_AUDIO", "mpeg2-aac-audio" },
    { C_ENUM(GST_MTS_DESC_FLEX_MUX_TIMING), "GST_MTS_DESC_FLEX_MUX_TIMING", "flex-mux-timing" },
    { C_ENUM(GST_MTS_DESC_MPEG4_TEXT), "GST_MTS_DESC_MPEG4_TEXT", "mpeg4-text" },
    { C_ENUM(GST_MTS_DESC_MPEG4_AUDIO_EXTENSION), "GST_MTS_DESC_MPEG4_AUDIO_EXTENSION", "mpeg4-audio-extension" },
    { C_ENUM(GST_MTS_DESC_AUXILIARY_VIDEO_STREAM), "GST_MTS_DESC_AUXILIARY_VIDEO_STREAM", "auxiliary-video-stream" },
    { C_ENUM(GST_MTS_DESC_SVC_EXTENSION), "GST_MTS_DESC_SVC_EXTENSION", "svc-extension" },
    { C_ENUM(GST_MTS_DESC_MVC_EXTENSION), "GST_MTS_DESC_MVC_EXTENSION", "mvc-extension" },
    { C_ENUM(GST_MTS_DESC_J2K_VIDEO), "GST_MTS_DESC_J2K_VIDEO", "j2k-video" },
    { C_ENUM(GST_MTS_DESC_MVC_OPERATION_POINT), "GST_MTS_DESC_MVC_OPERATION_POINT", "mvc-operation-point" },
    { C_ENUM(GST_MTS_DESC_MPEG2_STEREOSCOPIC_VIDEO_FORMAT), "GST_MTS_DESC_MPEG2_STEREOSCOPIC_VIDEO_FORMAT", "mpeg2-stereoscopic-video-format" },
    { C_ENUM(GST_MTS_DESC_STEREOSCOPIC_PROGRAM_INFO), "GST_MTS_DESC_STEREOSCOPIC_PROGRAM_INFO", "stereoscopic-program-info" },
    { C_ENUM(GST_MTS_DESC_STEREOSCOPIC_VIDEO_INFO), "GST_MTS_DESC_STEREOSCOPIC_VIDEO_INFO", "stereoscopic-video-info" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsDescriptorType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_misc_descriptor_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_DESC_DTG_LOGICAL_CHANNEL), "GST_MTS_DESC_DTG_LOGICAL_CHANNEL", "channel" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsMiscDescriptorType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_scte_descriptor_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_DESC_SCTE_STUFFING), "GST_MTS_DESC_SCTE_STUFFING", "stuffing" },
    { C_ENUM(GST_MTS_DESC_SCTE_AC3), "GST_MTS_DESC_SCTE_AC3", "ac3" },
    { C_ENUM(GST_MTS_DESC_SCTE_FRAME_RATE), "GST_MTS_DESC_SCTE_FRAME_RATE", "frame-rate" },
    { C_ENUM(GST_MTS_DESC_SCTE_EXTENDED_VIDEO), "GST_MTS_DESC_SCTE_EXTENDED_VIDEO", "extended-video" },
    { C_ENUM(GST_MTS_DESC_SCTE_COMPONENT_NAME), "GST_MTS_DESC_SCTE_COMPONENT_NAME", "component-name" },
    { C_ENUM(GST_MTS_DESC_SCTE_FREQUENCY_SPEC), "GST_MTS_DESC_SCTE_FREQUENCY_SPEC", "frequency-spec" },
    { C_ENUM(GST_MTS_DESC_SCTE_MODULATION_PARAMS), "GST_MTS_DESC_SCTE_MODULATION_PARAMS", "modulation-params" },
    { C_ENUM(GST_MTS_DESC_SCTE_TRANSPORT_STREAM_ID), "GST_MTS_DESC_SCTE_TRANSPORT_STREAM_ID", "transport-stream-id" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsSCTEDescriptorType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_registration_id_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_REGISTRATION_0), "GST_MTS_REGISTRATION_0", "0" },
    { C_ENUM(GST_MTS_REGISTRATION_AC_3), "GST_MTS_REGISTRATION_AC_3", "ac-3" },
    { C_ENUM(GST_MTS_REGISTRATION_CUEI), "GST_MTS_REGISTRATION_CUEI", "cuei" },
    { C_ENUM(GST_MTS_REGISTRATION_drac), "GST_MTS_REGISTRATION_drac", "drac" },
    { C_ENUM(GST_MTS_REGISTRATION_DTS1), "GST_MTS_REGISTRATION_DTS1", "dts1" },
    { C_ENUM(GST_MTS_REGISTRATION_DTS2), "GST_MTS_REGISTRATION_DTS2", "dts2" },
    { C_ENUM(GST_MTS_REGISTRATION_DTS3), "GST_MTS_REGISTRATION_DTS3", "dts3" },
    { C_ENUM(GST_MTS_REGISTRATION_BSSD), "GST_MTS_REGISTRATION_BSSD", "bssd" },
    { C_ENUM(GST_MTS_REGISTRATION_EAC3), "GST_MTS_REGISTRATION_EAC3", "eac3" },
    { C_ENUM(GST_MTS_REGISTRATION_ETV1), "GST_MTS_REGISTRATION_ETV1", "etv1" },
    { C_ENUM(GST_MTS_REGISTRATION_GA94), "GST_MTS_REGISTRATION_GA94", "ga94" },
    { C_ENUM(GST_MTS_REGISTRATION_HDMV), "GST_MTS_REGISTRATION_HDMV", "hdmv" },
    { C_ENUM(GST_MTS_REGISTRATION_KLVA), "GST_MTS_REGISTRATION_KLVA", "klva" },
    { C_ENUM(GST_MTS_REGISTRATION_OPUS), "GST_MTS_REGISTRATION_OPUS", "opus" },
    { C_ENUM(GST_MTS_REGISTRATION_TSHV), "GST_MTS_REGISTRATION_TSHV", "tshv" },
    { C_ENUM(GST_MTS_REGISTRATION_VC_1), "GST_MTS_REGISTRATION_VC_1", "vc-1" },
    { C_ENUM(GST_MTS_REGISTRATION_AC_4), "GST_MTS_REGISTRATION_AC_4", "ac-4" },
    { C_ENUM(GST_MTS_REGISTRATION_OTHER_HEVC), "GST_MTS_REGISTRATION_OTHER_HEVC", "other-hevc" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsRegistrationId"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_iso639_audio_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_AUDIO_TYPE_UNDEFINED), "GST_MPEGTS_AUDIO_TYPE_UNDEFINED", "undefined" },
    { C_ENUM(GST_MPEGTS_AUDIO_TYPE_CLEAN_EFFECTS), "GST_MPEGTS_AUDIO_TYPE_CLEAN_EFFECTS", "clean-effects" },
    { C_ENUM(GST_MPEGTS_AUDIO_TYPE_HEARING_IMPAIRED), "GST_MPEGTS_AUDIO_TYPE_HEARING_IMPAIRED", "hearing-impaired" },
    { C_ENUM(GST_MPEGTS_AUDIO_TYPE_VISUAL_IMPAIRED_COMMENTARY), "GST_MPEGTS_AUDIO_TYPE_VISUAL_IMPAIRED_COMMENTARY", "visual-impaired-commentary" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsIso639AudioType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

/* enumerations from "gstmpegtssection.h" */

GType
gst_mpegts_section_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_SECTION_UNKNOWN), "GST_MPEGTS_SECTION_UNKNOWN", "unknown" },
    { C_ENUM(GST_MPEGTS_SECTION_PAT), "GST_MPEGTS_SECTION_PAT", "pat" },
    { C_ENUM(GST_MPEGTS_SECTION_PMT), "GST_MPEGTS_SECTION_PMT", "pmt" },
    { C_ENUM(GST_MPEGTS_SECTION_CAT), "GST_MPEGTS_SECTION_CAT", "cat" },
    { C_ENUM(GST_MPEGTS_SECTION_TSDT), "GST_MPEGTS_SECTION_TSDT", "tsdt" },
    { C_ENUM(GST_MPEGTS_SECTION_EIT), "GST_MPEGTS_SECTION_EIT", "eit" },
    { C_ENUM(GST_MPEGTS_SECTION_NIT), "GST_MPEGTS_SECTION_NIT", "nit" },
    { C_ENUM(GST_MPEGTS_SECTION_BAT), "GST_MPEGTS_SECTION_BAT", "bat" },
    { C_ENUM(GST_MPEGTS_SECTION_SDT), "GST_MPEGTS_SECTION_SDT", "sdt" },
    { C_ENUM(GST_MPEGTS_SECTION_TDT), "GST_MPEGTS_SECTION_TDT", "tdt" },
    { C_ENUM(GST_MPEGTS_SECTION_TOT), "GST_MPEGTS_SECTION_TOT", "tot" },
    { C_ENUM(GST_MPEGTS_SECTION_SIT), "GST_MPEGTS_SECTION_SIT", "sit" },
    { C_ENUM(GST_MPEGTS_SECTION_ATSC_TVCT), "GST_MPEGTS_SECTION_ATSC_TVCT", "atsc-tvct" },
    { C_ENUM(GST_MPEGTS_SECTION_ATSC_CVCT), "GST_MPEGTS_SECTION_ATSC_CVCT", "atsc-cvct" },
    { C_ENUM(GST_MPEGTS_SECTION_ATSC_MGT), "GST_MPEGTS_SECTION_ATSC_MGT", "atsc-mgt" },
    { C_ENUM(GST_MPEGTS_SECTION_ATSC_ETT), "GST_MPEGTS_SECTION_ATSC_ETT", "atsc-ett" },
    { C_ENUM(GST_MPEGTS_SECTION_ATSC_EIT), "GST_MPEGTS_SECTION_ATSC_EIT", "atsc-eit" },
    { C_ENUM(GST_MPEGTS_SECTION_ATSC_STT), "GST_MPEGTS_SECTION_ATSC_STT", "atsc-stt" },
    { C_ENUM(GST_MPEGTS_SECTION_ATSC_RRT), "GST_MPEGTS_SECTION_ATSC_RRT", "atsc-rrt" },
    { C_ENUM(GST_MPEGTS_SECTION_SCTE_SIT), "GST_MPEGTS_SECTION_SCTE_SIT", "scte-sit" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsSectionType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_section_table_id_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MTS_TABLE_ID_PROGRAM_ASSOCIATION), "GST_MTS_TABLE_ID_PROGRAM_ASSOCIATION", "program-association" },
    { C_ENUM(GST_MTS_TABLE_ID_CONDITIONAL_ACCESS), "GST_MTS_TABLE_ID_CONDITIONAL_ACCESS", "conditional-access" },
    { C_ENUM(GST_MTS_TABLE_ID_TS_PROGRAM_MAP), "GST_MTS_TABLE_ID_TS_PROGRAM_MAP", "ts-program-map" },
    { C_ENUM(GST_MTS_TABLE_ID_TS_DESCRIPTION), "GST_MTS_TABLE_ID_TS_DESCRIPTION", "ts-description" },
    { C_ENUM(GST_MTS_TABLE_ID_14496_SCENE_DESCRIPTION), "GST_MTS_TABLE_ID_14496_SCENE_DESCRIPTION", "14496-scene-description" },
    { C_ENUM(GST_MTS_TABLE_ID_14496_OBJET_DESCRIPTOR), "GST_MTS_TABLE_ID_14496_OBJET_DESCRIPTOR", "14496-objet-descriptor" },
    { C_ENUM(GST_MTS_TABLE_ID_METADATA), "GST_MTS_TABLE_ID_METADATA", "metadata" },
    { C_ENUM(GST_MTS_TABLE_ID_IPMP_CONTROL_INFORMATION), "GST_MTS_TABLE_ID_IPMP_CONTROL_INFORMATION", "ipmp-control-information" },
    { C_ENUM(GST_MTS_TABLE_ID_14496_SECTION), "GST_MTS_TABLE_ID_14496_SECTION", "14496-section" },
    { C_ENUM(GST_MTS_TABLE_ID_23001_11_SECTION), "GST_MTS_TABLE_ID_23001_11_SECTION", "23001-11-section" },
    { C_ENUM(GST_MTS_TABLE_ID_23001_10_SECTION), "GST_MTS_TABLE_ID_23001_10_SECTION", "23001-10-section" },
    { C_ENUM(GST_MTS_TABLE_ID_DSM_CC_MULTIPROTO_ENCAPSULATED_DATA), "GST_MTS_TABLE_ID_DSM_CC_MULTIPROTO_ENCAPSULATED_DATA", "dsm-cc-multiproto-encapsulated-data" },
    { C_ENUM(GST_MTS_TABLE_ID_DSM_CC_U_N_MESSAGES), "GST_MTS_TABLE_ID_DSM_CC_U_N_MESSAGES", "dsm-cc-u-n-messages" },
    { C_ENUM(GST_MTS_TABLE_ID_DSM_CC_DOWNLOAD_DATA_MESSAGES), "GST_MTS_TABLE_ID_DSM_CC_DOWNLOAD_DATA_MESSAGES", "dsm-cc-download-data-messages" },
    { C_ENUM(GST_MTS_TABLE_ID_DSM_CC_STREAM_DESCRIPTORS), "GST_MTS_TABLE_ID_DSM_CC_STREAM_DESCRIPTORS", "dsm-cc-stream-descriptors" },
    { C_ENUM(GST_MTS_TABLE_ID_DSM_CC_PRIVATE_DATA), "GST_MTS_TABLE_ID_DSM_CC_PRIVATE_DATA", "dsm-cc-private-data" },
    { C_ENUM(GST_MTS_TABLE_ID_DSM_CC_ADDRESSABLE_SECTIONS), "GST_MTS_TABLE_ID_DSM_CC_ADDRESSABLE_SECTIONS", "dsm-cc-addressable-sections" },
    { C_ENUM(GST_MTS_TABLE_ID_UNSET), "GST_MTS_TABLE_ID_UNSET", "unset" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsSectionTableID"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

GType
gst_mpegts_stream_type_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_RESERVED_00), "GST_MPEGTS_STREAM_TYPE_RESERVED_00", "reserved-00" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_MPEG1), "GST_MPEGTS_STREAM_TYPE_VIDEO_MPEG1", "video-mpeg1" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_MPEG2), "GST_MPEGTS_STREAM_TYPE_VIDEO_MPEG2", "video-mpeg2" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_AUDIO_MPEG1), "GST_MPEGTS_STREAM_TYPE_AUDIO_MPEG1", "audio-mpeg1" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_AUDIO_MPEG2), "GST_MPEGTS_STREAM_TYPE_AUDIO_MPEG2", "audio-mpeg2" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_PRIVATE_SECTIONS), "GST_MPEGTS_STREAM_TYPE_PRIVATE_SECTIONS", "private-sections" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_PRIVATE_PES_PACKETS), "GST_MPEGTS_STREAM_TYPE_PRIVATE_PES_PACKETS", "private-pes-packets" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_MHEG), "GST_MPEGTS_STREAM_TYPE_MHEG", "mheg" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_DSM_CC), "GST_MPEGTS_STREAM_TYPE_DSM_CC", "dsm-cc" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_H_222_1), "GST_MPEGTS_STREAM_TYPE_H_222_1", "h-222-1" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_DSMCC_A), "GST_MPEGTS_STREAM_TYPE_DSMCC_A", "dsmcc-a" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_DSMCC_B), "GST_MPEGTS_STREAM_TYPE_DSMCC_B", "dsmcc-b" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_DSMCC_C), "GST_MPEGTS_STREAM_TYPE_DSMCC_C", "dsmcc-c" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_DSMCC_D), "GST_MPEGTS_STREAM_TYPE_DSMCC_D", "dsmcc-d" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_AUXILIARY), "GST_MPEGTS_STREAM_TYPE_AUXILIARY", "auxiliary" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_AUDIO_AAC_ADTS), "GST_MPEGTS_STREAM_TYPE_AUDIO_AAC_ADTS", "audio-aac-adts" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_MPEG4), "GST_MPEGTS_STREAM_TYPE_VIDEO_MPEG4", "video-mpeg4" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_AUDIO_AAC_LATM), "GST_MPEGTS_STREAM_TYPE_AUDIO_AAC_LATM", "audio-aac-latm" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SL_FLEXMUX_PES_PACKETS), "GST_MPEGTS_STREAM_TYPE_SL_FLEXMUX_PES_PACKETS", "sl-flexmux-pes-packets" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SL_FLEXMUX_SECTIONS), "GST_MPEGTS_STREAM_TYPE_SL_FLEXMUX_SECTIONS", "sl-flexmux-sections" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_SYNCHRONIZED_DOWNLOAD), "GST_MPEGTS_STREAM_TYPE_SYNCHRONIZED_DOWNLOAD", "synchronized-download" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_METADATA_PES_PACKETS), "GST_MPEGTS_STREAM_TYPE_METADATA_PES_PACKETS", "metadata-pes-packets" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_METADATA_SECTIONS), "GST_MPEGTS_STREAM_TYPE_METADATA_SECTIONS", "metadata-sections" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_METADATA_DATA_CAROUSEL), "GST_MPEGTS_STREAM_TYPE_METADATA_DATA_CAROUSEL", "metadata-data-carousel" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_METADATA_OBJECT_CAROUSEL), "GST_MPEGTS_STREAM_TYPE_METADATA_OBJECT_CAROUSEL", "metadata-object-carousel" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_METADATA_SYNCHRONIZED_DOWNLOAD), "GST_MPEGTS_STREAM_TYPE_METADATA_SYNCHRONIZED_DOWNLOAD", "metadata-synchronized-download" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_MPEG2_IPMP), "GST_MPEGTS_STREAM_TYPE_MPEG2_IPMP", "mpeg2-ipmp" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_H264), "GST_MPEGTS_STREAM_TYPE_VIDEO_H264", "video-h264" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_AUDIO_AAC_CLEAN), "GST_MPEGTS_STREAM_TYPE_AUDIO_AAC_CLEAN", "audio-aac-clean" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_MPEG4_TIMED_TEXT), "GST_MPEGTS_STREAM_TYPE_MPEG4_TIMED_TEXT", "mpeg4-timed-text" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_RVC), "GST_MPEGTS_STREAM_TYPE_VIDEO_RVC", "video-rvc" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_H264_SVC_SUB_BITSTREAM), "GST_MPEGTS_STREAM_TYPE_VIDEO_H264_SVC_SUB_BITSTREAM", "video-h264-svc-sub-bitstream" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_H264_MVC_SUB_BITSTREAM), "GST_MPEGTS_STREAM_TYPE_VIDEO_H264_MVC_SUB_BITSTREAM", "video-h264-mvc-sub-bitstream" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_JP2K), "GST_MPEGTS_STREAM_TYPE_VIDEO_JP2K", "video-jp2k" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_MPEG2_STEREO_ADDITIONAL_VIEW), "GST_MPEGTS_STREAM_TYPE_VIDEO_MPEG2_STEREO_ADDITIONAL_VIEW", "video-mpeg2-stereo-additional-view" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_H264_STEREO_ADDITIONAL_VIEW), "GST_MPEGTS_STREAM_TYPE_VIDEO_H264_STEREO_ADDITIONAL_VIEW", "video-h264-stereo-additional-view" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_VIDEO_HEVC), "GST_MPEGTS_STREAM_TYPE_VIDEO_HEVC", "video-hevc" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_IPMP_STREAM), "GST_MPEGTS_STREAM_TYPE_IPMP_STREAM", "ipmp-stream" },
    { C_ENUM(GST_MPEGTS_STREAM_TYPE_USER_PRIVATE_EA), "GST_MPEGTS_STREAM_TYPE_USER_PRIVATE_EA", "user-private-ea" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GstMpegtsStreamType"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

/* Generated data ends here */

